# Introduction

Welcome to the Auroris - Simplifying Drug Discovery Data Curation

--- 

## What is Auroris?

Auroris is a Python library designed to assist researchers and scientists in managing, cleaning, and preparing data relevant to drug discovery. Auroris will implement a range of techniques to handle, transform, filter, analyze, or visualize the diverse data types commonly encountered in drug discovery. 

Currently, Auroris supports curation for small molecules, with plans to extend to other modalities in drug discovery. The curation module for small molecules includes:

- 🗄️ Molecule Standardization: Ensures that each molecule is represented in a uniform and unambiguous form.

- 🏷️ Detection of Duplicate Molecules with Contradictory Labels: Identifies and resolves inconsistencies in activity data for each molecule.

- ⛰️ Detection of Activity Cliffs Between Stereoisomers: Identifies significant differences in activity between stereoisomers.

- 🔍Outlier Detection and Visualization: Detects and visualizes outliers in molecular activity data.

- 📽️ Visualization of Molecular Distribution in Chemical Space: Provides graphical representations of molecular distributions.

Reproducibility and transparency are core to the mission of Polaris. That’s why with Auroris, you can also automatically generate detailed reports summarizing the changes that happened to a dataset during curation. Through an intuitive API, you can easily define complex curation workflows. Once defined, that workflow is serializable and thus reproducible so you can transparently share how you curated the dataset.
 



## Where to next?
---

**:fontawesome-solid-rocket:  Quickstart**

Dive deeper into the Auroris code and learn how to curate data for your ML-powered drug discovery program. 

[:material-arrow-right: Let's get started](./tutorials/getting_started.ipynb)

---

**:fontawesome-solid-code:  API Reference**

Explore the technical documentation here to delve into the inner workings of the code. Gain insights into the intricate details of how different methods and classes function.

[:material-arrow-right: Let's get started](./api/curator.md)

---

**:fontawesome-solid-comments:  Community**

We're excited to have you join us in revolutionizing drug discovery data curation! Explore Auroris and the broader Polaris ecosystem it is part of, provide feedback, share your use cases, and collaborate with us to enhance and expand the capabilities of Auroris for the benefit of the drug discovery community.

[:material-arrow-right: Let's get started](https://discord.gg/vBFd8p6H7u)

---